@@ -3,6 +3,6 @@ import os
 import httprpclib
 
 cfg = os.path.join(os.path.dirname(__file__), 'reviewboard.cfg')
-rpc = httprpclib.ServerProxy('http://demo.review-board.org/', cfg)
+rpc = httprpclib.ServerProxy('http://demo.reviewboard.org/', cfg)
 print rpc.get_repositories()
 print rpc.get_groups()
